Astropy affiliated package template
===================================

.. image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
    :target: http://www.astropy.org
    :alt: Powered by Astropy Badge

This is the template for affiliated packages of the Astropy project.

Astropy affiliated packages are astronomy-related Python packages that
have requested to be part of the Astropy project’s community.
Such packages can make use of the setup, installation, and documentation
infrastructure developed for the ``astropy`` core package simply by
using this template to lay out the package.

For more information, see:

* `Detailed instructions for using this template <http://astropy.readthedocs.org/en/latest/development/affiliated-packages.html>`_
* `The Affiliated Packages section of the Astropy web site <http://affiliated.astropy.org>`_
* `This template's Github code repository <https://github.com/astropy/package-template>`_

Status reports for developers
-----------------------------

.. image:: https://travis-ci.org/astropy/package-template.png?branch=master
    :target: https://travis-ci.org/astropy/package-template
    :alt: Test Status
